import { QueryList, AfterContentInit, EventEmitter } from '@angular/core';
import { IgxSplitterPaneComponent } from './splitter-pane/splitter-pane.component';
/**
 * An enumeration that defines the `SplitterComponent` panes orientation.
 * @export
 * @enum {number}
 */
export declare enum SplitterType {
    Horizontal = 0,
    Vertical = 1
}
/**
 * Provides reference to `SplitterComponent` component.
 * The splitter consists of resizable panes that can be arranged either vertically or horizontally.
 * There is a gripper between each couple of panes that helps widen or shrink them.
 * @export
 * @class SplitterComponent
 * @implements AfterContentInit
 */
export declare class IgxSplitterComponent implements AfterContentInit {
    private _type;
    /**
     * Sets/gets `SplitterComponent` orientation.
     * @type SplitterType
     * @memberof SplitterComponent
     */
    get type(): SplitterType;
    set type(value: SplitterType);
    /**
     * Event emitted when panes collection is changed.
     */
    panesChange: EventEmitter<IgxSplitterPaneComponent[]>;
    /**
     * A list of all `IgxSplitterPaneComponent` items.
     * @memberof SplitterComponent
     */
    panes: QueryList<IgxSplitterPaneComponent>;
    /**
     * Gets the `flex-direction` property of the current `SplitterComponent`.
     * @readonly
     * @type string
     * @memberof SplitterComponent
     */
    get direction(): string;
    /**
     * Sets/gets the `overflow` property of the current `SplitterComponent`.
     * @memberof SplitterComponent
     */
    overflow: string;
    /**
     * Sets/gets the `display` property of the current `SplitterComponent`.
     * @memberof SplitterComponent
     */
    display: string;
    /**
     * A field that holds the initial size of the main `IgxSplitterPaneComponent` in each couple of panes devided by a gripper.
     * @private
     * @memberof SplitterComponent
     */
    private initialPaneSize;
    /**
     * A field that holds the initial size of the sibling `IgxSplitterPaneComponent` in each couple of panes devided by a gripper.
     * @private
     * @memberof SplitterComponent
     */
    private initialSiblingSize;
    /**
     * The main `IgxSplitterPaneComponent` in each couple of panes devided by a gripper.
     * @private
     * @memberof SplitterComponent
     */
    private pane;
    /**
     * The sibling `IgxSplitterPaneComponent` in each couple of panes devided by a gripper.
     * @private
     * @memberof SplitterComponent
     */
    private sibling;
    /** @hidden @internal */
    ngAfterContentInit(): void;
    /**
     * @hidden @internal
     * This method performs some initialization logic when the user starts dragging the gripper between each couple of panes.
     * @param  {IgxSplitterPaneComponent} pane
     * The main `IgxSplitterPaneComponent` associated with the currently dragged `SplitBarComponent`.
     */
    onMoveStart(pane: IgxSplitterPaneComponent): void;
    /**
     * @hidden @internal
     * This method performs some calculations concerning the sizes each couple of panes while the gripper between them is being dragged.
     * @param  {number} delta The differnce along the X (or Y) axis between the initial and the current point while dragging the gripper.
     */
    onMoving(delta: number): void;
    /**
     * Toggles pane visibility.
     * @param pane - The pane to be hidden/shown.
     */
    togglePane(pane: IgxSplitterPaneComponent): void;
    /**
     * @hidden @internal
     * This method takes care for assigning an `order` property on each `IgxSplitterPaneComponent`.
     */
    private assignFlexOrder;
    /** @hidden @internal */
    getPaneSiblingsByOrder(order: number, barIndex: number): Array<IgxSplitterPaneComponent>;
    /** @hidden @internal */
    private _getSiblings;
}
